@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.3   2012/08/02
+ * Version: 0.1.8   2013/01/06
  */
 
 #include "internal.h"
@@ -90,11 +90,11 @@ static void ccs_memory_free(const void *ptr, const enum ccs_policy_id type)
 }
 
 /**
- * ccs_struct_used_by_io_buffer - Check whether the list element is used by /proc/ccs/ users or not.
+ * ccs_struct_used_by_io_buffer - Check whether the list element is used by /proc/caitsith/ users or not.
  *
  * @element: Pointer to "struct list_head".
  *
- * Returns true if @element is used by /proc/ccs/ users, false otherwise.
+ * Returns true if @element is used by /proc/caitsith/ users, false otherwise.
  */
 static bool ccs_struct_used_by_io_buffer(const struct list_head *element)
 {
@@ -119,12 +119,12 @@ static bool ccs_struct_used_by_io_buffer(const struct list_head *element)
 }
 
 /**
- * ccs_name_used_by_io_buffer - Check whether the string is used by /proc/ccs/ users or not.
+ * ccs_name_used_by_io_buffer - Check whether the string is used by /proc/caitsith/ users or not.
  *
  * @string: String to check.
  * @size:   Memory allocated for @string .
  *
- * Returns true if @string is used by /proc/ccs/ users, false otherwise.
+ * Returns true if @string is used by /proc/caitsith/ users, false otherwise.
  */
 static bool ccs_name_used_by_io_buffer(const char *string, const size_t size)
 {
@@ -479,7 +479,8 @@ static void ccs_collect_entry(void)
 		struct ccs_domain_info *domain;
 		struct ccs_domain_info *tmp;
 		list_for_each_entry_safe(domain, tmp, &ccs_domain_list, list) {
-			if (ccs_domain_used_by_task(domain))
+			if (domain == &ccs_kernel_domain ||
+			    ccs_domain_used_by_task(domain))
 				continue;
 			ccs_try_to_gc(CCS_ID_DOMAIN, &domain->list);
 		}
@@ -576,7 +577,7 @@ out:
 }
 
 /**
- * ccs_notify_gc - Register/unregister /proc/ccs/ users.
+ * ccs_notify_gc - Register/unregister /proc/caitsith/ users.
  *
  * @head:        Pointer to "struct ccs_io_buffer".
  * @is_register: True if register, false if unregister.
